@@ -31,6 +31,7 @@ load_dotenv()
 MQTT_HOST = os.getenv("MQTT_HOST", "dwd.tudelft.nl")
 MQTT_PORT = int(os.getenv("MQTT_PORT", "8883"))
 MQTT_SECURED = os.getenv("MQTT_SECURED", "True") == "True"
+DIGI_CERT_CA = os.getenv("DIGI_CERT_CA", "DigiCertCA.crt")
 
 class ThingMQTT:
 
@@ -70,7 +71,7 @@ class ThingMQTT:
         if (MQTT_SECURED):
             check_digi_cert_ca()
             self.mqtt_client.tls_set(
-                "DigiCertCA.crt", cert_reqs=ssl.CERT_NONE,
+                DIGI_CERT_CA, cert_reqs=ssl.CERT_NONE,
                 tls_version=ssl.PROTOCOL_TLSv1_2)
 
             self.mqtt_client.tls_insecure_set(True)
